FUNCTION integral(fun,a,b)

! Numerical integration of the function fun over [a,b].
! This is the interface to the external integrating function only.

USE jm_constants

IMPLICIT none

REAL(KIND=dp), INTENT(IN) :: a, b
REAL(KIND=dp), EXTERNAL   :: fun
REAL(KIND=dp)             :: integral
REAL(KIND=dp)             :: err
REAL(KIND=dp)             :: work(0:7999)


! See http://momonga.t.u-tokyo.ac.jp/~ooura/
! Not using variables to speed up execution
!             lenw  tiny      epsrel  work(0:lenw-1)
CALL intdeini(8000, 1.0D-307, 1.0d-8, work)

CALL intde(fun, a, b, work, integral, err)

!IF (err < 0) CALL show_warning('integral', 'requested accuracy not achieved')

RETURN
END FUNCTION integral

!***********************************************************************

FUNCTION integral_inf(fun,a)

! Numerical integration of the function fun over [a, infinity] 
! This is the interface to the external integrating function only.

USE jm_constants

IMPLICIT none

REAL(KIND=dp), INTENT(in) :: a
REAL(KIND=dp), EXTERNAL   :: fun
REAL(KIND=dp)             :: integral_inf
REAL(KIND=dp)             :: err
REAL(KIND=dp)             :: work(7999)


! See http://momonga.t.u-tokyo.ac.jp/~ooura/
! Not using variables to speed up execution
!              lenw  tiny      epsrel  work(0:lenw-1)
CALL intdeiini(8000, 1.0D-307, 1.0d-8, work)

CALL intdei(fun,a,work,integral_inf,err)

!IF (err < 0) CALL show_warning('integral', 'requested accuracy not achieved')

RETURN
END FUNCTION integral_inf

!***********************************************************************