FUNCTION jm(i,j,nonrel_scheme)

! Computes the elements of the J-matrix.
! If optional parameter nonrel_scheme is set, non-relativistic
! formula is used, independent from current value of scheme. 

USE jm_constants
USE jm_globals, ONLY : ntrunc, scheme, projectile, v_light

IMPLICIT none

INTEGER, INTENT(IN)           :: i, j
INTEGER, OPTIONAL, INTENT(IN) :: nonrel_scheme
REAL(KIND=dp)                 :: jm
REAL(KIND=dp)                 :: psipsi, fifi


IF (scheme == 'relativistic' .AND. .NOT. PRESENT(nonrel_scheme) ) THEN

  IF (i+1 <= ntrunc .AND. j+1 <= ntrunc) THEN
    jm = -projectile%e * fifi(ntrunc-i-1, ntrunc-j-1)

  ELSE IF (i+1 <= ntrunc .AND. j+1 >  ntrunc) THEN
    jm = v_light * psipsi(ntrunc-i-1, j-ntrunc)

  ELSE IF (i+1 >  ntrunc .AND. j+1 >  ntrunc) THEN
    jm = -(projectile%e + two * v_light**2) * psipsi(i-ntrunc, j-ntrunc)

  ELSE IF (i+1 >  ntrunc .AND. j+1 <= ntrunc) THEN 
    jm = v_light * psipsi(ntrunc-j-1, i-ntrunc)

  ENDIF
  
ELSE  ! Non-relativistic formulas
  
  jm = half * psipsi(i,j)  -  projectile%k**2 / two * fifi(i,j)
  
ENDIF

RETURN
END FUNCTION jm

!***********************************************************************
