FUNCTION t(n)

! Calculates numerical value of tangent to the phase shift 
! for the given <n>.

USE jm_constants
USE jm_interfaces
USE jm_globals, ONLY: scheme, projectile, v_light


IMPLICIT none

INTEGER, INTENT(IN) :: n
REAL(KIND=dp)       :: t
REAL(KIND=dp)       :: g
REAL(KIND=dp)       :: eps, tmp, gn, jmn


! Calculate element of matrix aproximating Green function
gn = g(n-1,n-1)

SELECT CASE(scheme)
CASE('relativistic')

  ! Non-relativistic element Jm, so optional argument to function jm is passed
  jmn = jm(n, n-1, 1)
  eps = sqrt( projectile%e / (projectile%e + two * v_light**2) )
  tmp = two * eps * v_light / projectile%k

CASE('non-relativistic')

  jmn = jm(n, n-1)
  tmp = one

END SELECT

t = - ( s(n-1) + tmp * gn * jmn * s(n) ) / ( c(n-1) + tmp * gn * jmn * c(n) )

RETURN
END FUNCTION t

!***********************************************************************