PROGRAM JMATRIX

! JMATRIX - program for calculating scattering phase shifts 
!           using the J-matrix method
!
! WWW homepage: http://jmatrix.sylas.info
!
! Author: Pawel Syty
!         Department of Theoretical Physics And Quantum Informatics
!         Faculty of Applied Physics And Mathematics
!         Gdansk University of Technology, Gdansk, Poland
! E-mail: sylas@mif.pg.gda.pl
! WWW:    http://sylas.info
! Date  : January 2007
!
! Please read provided documentation prior to using the program.
! All comments and suggestions are welcome.


! This is the main segment of the JMATRIX program.
! It only collects the input and output filenames, calls subroutines reading 
! input file and calculating phase shifts, and measures time of computations.


IMPLICIT NONE

CHARACTER (LEN=100) :: fin, fout
REAL                :: time_start, time_end, time, time_s
INTEGER             :: time_h, time_m
!$ INTEGER          :: OMP_get_num_procs


! Write program and (if available) OpenMP information 
PRINT '(/A)', 'Starting the JMATRIX program.'
PRINT*, 'Version: 2.01, 28/01/2007'
!$ PRINT '(A,I3)', ' Compiled with OpenMP support. No. of CPUs available: ', &
!$                   OMP_get_num_procs()

! Ask user for name of the input file
PRINT '(/A)', 'Enter name of the input file  ( <cr> = jm.inp ).'
READ '(A)', fin
IF (fin == '') fin = 'jm.inp'

CALL loadparams(fin)   ! Read the input data

! Ask user for root name of the output files
PRINT '(/A)', 'The following output files will be created:'
PRINT*, '<root>     - phase shifts as function of the basis size,'
PRINT*, '<root>.avg - averaged phase shifts as function of the basis size,'
PRINT*, '<root>.en  - phase shifts as function of energy of the projectile,'
PRINT*, '<root>.rms - root mean squared error (for square-well potential only),'
PRINT*, 'saved.vn.<nend>  - elements of the truncated potential.'
PRINT '(A)', 'Enter root name of the output files ( <cr> = jm.out ).'
READ '(A)',  fout
IF (fout == '') fout = 'jm.out'


! Save CPU time at start of the computations
CALL cpu_time(time_start)


! Call the main loop of the program.  
! It calculates phase shifts for <ntrunc> = <nstart>... <nend>
! (look for the convergence for a fixed energy <e>).
! Then collects phase shifts for given energies 
! from range [<estart>, <eend>] for <ntrunc> = <nend>

CALL control_calc_delta(fout)     


! Calculate and display time of computations
CALL cpu_time(time_end)
time = time_end - time_start

time_h = int(time / 3600)
time_m = int((time - time_h*3600) / 60)
time_s = time - time_m*60 - time_h*3600

PRINT '(/A,I5,A,I2,A,F5.2,A)', 'Elapsed CPU time: ', &
       time_h, ' hour(s), ', time_m, ' minute(s), ', time_s, ' second(s).'

PRINT '(/A/)', 'JMATRIX complete.'

END PROGRAM JMATRIX
